@@ -1,8 +1,8 @@
-# musglyphs.rb -- musglyphs.scm and cmn-glyphs.lisp --> musglyphs.rb -*- snd-ruby -*-
+# musglyphs.rb -- musglyphs.scm and cmn-glyphs.lisp --> musglyphs.rb
 
 # Translator: Michael Scholz <mi-scholz@users.sourceforge.net>
-# Created: Wed Apr 06 00:47:44 CEST 2005
-# Changed: Fri Jul 06 01:53:43 CEST 2007
+# Created: 2005/04/06 00:47:44
+# Changed: 2018/04/15 22:56:24
 
 # Commentary:
 #
@@ -178,7 +178,8 @@ module Musglyphs
 
     def draw
       unless @pathlist.empty?
-        draw_lines(@pathlist.flatten.compact, @snd, @chn, @ax)
+        cr = channel_widgets(@snd, @chn)[17]
+        draw_lines(@pathlist.flatten.compact, @snd, @chn, @ax, cr)
       end
       @pathlist.clear
       self
@@ -186,7 +187,8 @@ module Musglyphs
 
     def fill_in
       unless @pathlist.empty?
-        fill_polygon(@pathlist.flatten.compact, @snd, @chn, @ax)
+        cr = channel_widgets(@snd, @chn)[17]
+        fill_polygon(@pathlist.flatten.compact, @snd, @chn, @ax, cr)
       end
       @pathlist.clear
       self
@@ -201,7 +203,8 @@ module Musglyphs
     end
     
     def circle(x0, y0, rad)
-      draw_dot(to_x(x0), to_y(y0), (@size * rad * 2.0).floor, @snd, @chn, @ax)
+      cr = channel_widgets(@snd, @chn)[17]
+      draw_dot(to_x(x0), to_y(y0), (@size * rad * 2).floor, @snd, @chn, @ax, cr)
       self
     end
 
@@ -1915,7 +1918,6 @@ include Musglyphs
 
 def musglyphs_test_1
   Musglyphs.public_methods.sort.each do |dr|
-    break if c_g?
     next unless dr =~ /^draw_/
     clm_print("\n%s", dr)
     update_time_graph(0, 0)
@@ -2015,7 +2017,6 @@ def musglyphs_test
    :draw_128th_rest,
    :draw_measure_rest,
    :draw_double_whole_rest].each do |dr|
-    break if c_g?
     clm_print("\n%s", dr)
     update_time_graph(0, 0)
     if dr == :draw_trill_sections or dr == :draw_arpeggios
