@@ -2007,7 +2007,7 @@ static s7_pointer g_save_region(s7_scheme *sc, s7_pointer args)
 
   fp = s7_cadr(p);
   if (fp == Xen_false)
-    head_type = MUS_NEXT;
+    head_type = default_output_header_type(ss); /* was MUS_NEXT, 28-Jul-23 */
   else
     {
       if (!s7_is_integer(fp))
@@ -2061,7 +2061,7 @@ static Xen g_save_region(Xen n, Xen arg1, Xen arg2, Xen arg3, Xen arg4, Xen arg5
   const char *file = NULL, *com = NULL;
   int rg, true_args;
   mus_sample_t sample_type = MUS_OUT_SAMPLE_TYPE;
-  mus_header_t header_type = MUS_NEXT;
+  mus_header_t header_type = default_output_header_type(ss); /* was MUS_NEXT, 28-Jul-23 */
   Xen args[8]; 
   Xen keys[4];
   int orig_arg[4] = {0, 0, 0, 0};
