@@ -47,11 +47,11 @@
 
 #include "snd-strings.h"
 
-#define SND_DATE "4-Aug-25"
+#define SND_DATE "10-Oct-25"
 #ifndef SND_VERSION
-#define SND_VERSION "25.6"
+#define SND_VERSION "25.8"
 #endif
 #define SND_MAJOR_VERSION "25"
-#define SND_MINOR_VERSION "6"
+#define SND_MINOR_VERSION "8"
 
 #endif
