@@ -341,7 +341,7 @@ int main(int argc, char **argv)
   add_file("ffitest.c");
 
   add_file("/home/bil/dist/snd/s7webserver/s7webserver.cpp");
-  add_file("/home/bil/test/rad/newrad/scheme.cpp");
+  /* add_file("/home/bil/test/rad/newrad/scheme.cpp"); */
 
   add_file("/home/bil/test/grace/Source/CmSupport.cpp");
   add_file("/home/bil/test/grace/Source/Scheme.cpp");
